from ast import arg
from .stats import stats
from .zbcode import get_tree
import argparse

if __name__ == '__main__':
    parser=argparse.ArgumentParser(prog='cn-stats',description='获取中国国家统计局网站数据Python包')
    parser.add_argument('--tree', action='store_const', const='zb', help='列出指标代码')
    parser.add_argument('--dbcode', nargs='?', const='hgyd', default='hgyd', help='数据库代码')
    parser.add_argument('zbcode', help='指标代码', nargs='?')
    parser.add_argument('date', help='查询日期', nargs='?')
    args=parser.parse_args()
    if args.tree == 'zb':
        get_tree(args.tree, args.dbcode)
    else:
        r=stats(args.zbcode, args.date)
        for row in r:
            print(' '.join(row))




from os import stat
import requests
import time

header={
        'Accept-Encoding':'gzip, deflate, br',
        'Connection':'keep-alive',
        'Referer':'https://data.stats.gov.cn/easyquery.htm?cn=A01',
        'Host':'data.stats.gov.cn',
        'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36 Edg/99.0.1150.36',
        'X-Requested-With':'XMLHttpRequest',
        'Cookie':'_trs_uv=l0krufmy_6_30qm; JSESSIONID=JkGLaObMfWG3_P3_bNKa59cUydvE_nJDUpJOsskem4S-E-wgJeA7!-2135294552; u=1'
       }

def random_timestamp():
    return str(int(round(time.time() * 1000)))

def easyquery(code, datestr):
    url='https://data.stats.gov.cn/easyquery.htm'
    obj={'m': 'QueryData', 'dbcode': 'hgyd', 'rowcode': 'zb', 'colcode': 'sj',
    'wds': '[]',
    'dfwds': '[{"wdcode":"zb","valuecode":"'+code+'"},{"wdcode":"sj","valuecode":"'+datestr+'"}]',
    'k1': random_timestamp()
    }
    requests.packages.urllib3.disable_warnings()
    r = requests.post(url, data=obj, headers=header, verify=False)
    return r.json()


def stats(code, datestr):
    ret=easyquery(code, datestr)
    if ret['returncode'] == 200 :
        data_dict = {}
        for n in ret['returndata']['wdnodes']:
            if n['wdcode'] == 'zb':
                for i in n['nodes']:
                    data_dict[i['code']] = i['cname']

        result = []
        for n in ret['returndata']['datanodes']:
            if n['data']['hasdata'] == True:
                result.append([data_dict[n['wds'][0]['valuecode']],n['wds'][0]['valuecode'],n['wds'][1]['valuecode'],n['data']['strdata']])
        return result



import requests

header={
        'Accept-Encoding':'gzip, deflate, br',
        'Connection':'keep-alive',
        'Referer':'https://data.stats.gov.cn/easyquery.htm?cn=A01',
        'Host':'data.stats.gov.cn',
        'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.4844.51 Safari/537.36 Edg/99.0.1150.36',
        'X-Requested-With':'XMLHttpRequest',
        'Cookie':'_trs_uv=l0krufmy_6_30qm; JSESSIONID=JkGLaObMfWG3_P3_bNKa59cUydvE_nJDUpJOsskem4S-E-wgJeA7!-2135294552; u=1'
       }

def easyquery(id='zb', dbcode='hgyd'):
    url='https://data.stats.gov.cn/easyquery.htm'
    obj={'id': id, 'dbcode': dbcode, 'wdcode': 'zb', 'm': 'getTree'}
    requests.packages.urllib3.disable_warnings()
    r=requests.post(url, data=obj, headers=header, verify=False)
    return r.json()

def get_tree(id='zb', dbcode='hgyd'):
    for n in easyquery(id):
        print(n['id'], n['name'])
        if n['isParent']: get_tree(n['id'], dbcode)

if __name__ == '__main__':
    get_tree('zb')